@@ -18,7 +18,7 @@ def test_read_sdt(test_file_path, result_file_path, index):
 
     test_dataset = read_sdt(file_path=test_file_path, index=index)
     result_df = pd.read_csv(
-        result_file_path, skiprows=1, sep=r"\s+", dtype={"Delay": np.float, "Data": np.uint16}
+        result_file_path, skiprows=1, sep=r"\s+", dtype={"Delay": float, "Data": np.uint16}
     )
     result_df.Delay = result_df.Delay * 1e-9
     result_traces = pd.DataFrame([result_df.Data.values], columns=result_df.Delay)
