@@ -2,8 +2,7 @@
 
 import numpy as np
 
-from glotaran.builtin.models.kinetic_image.kinetic_image_matrix import \
-    kinetic_image_matrix
+from glotaran.builtin.models.kinetic_image.kinetic_image_matrix import kinetic_image_matrix
 
 from .spectral_irf import IrfGaussianCoherentArtifact
 
@@ -11,11 +10,11 @@ from .spectral_irf import IrfGaussianCoherentArtifact
 def kinetic_spectrum_matrix(dataset_descriptor=None, axis=None, index=None, irf=None):
 
     clp_label, matrix = kinetic_image_matrix(
-        dataset_descriptor, axis, index, dataset_descriptor.irf)
+        dataset_descriptor, axis, index, dataset_descriptor.irf
+    )
 
     if isinstance(dataset_descriptor.irf, IrfGaussianCoherentArtifact):
-        irf_clp_label, irf_matrix = \
-            dataset_descriptor.irf.calculate_coherent_artifact(axis)
+        irf_clp_label, irf_matrix = dataset_descriptor.irf.calculate_coherent_artifact(axis)
         if matrix is None:
             clp_label = irf_clp_label
             matrix = irf_matrix
