@@ -1,5 +1,5 @@
-from . import parameter, parameter_group
-
+from . import parameter
+from . import parameter_group
 
 Parameter = parameter.Parameter
 ParameterGroup = parameter_group.ParameterGroup
